@@ -1,5 +1,5 @@
 from .reader import open_run, open_sim
-from .writer import SimWriter
+from .writer import ExpWriter, SimWriter
 from .tempdir import TempSimulationDirectory
 
 
